CREATE TABLE `Config` (
	`id`		int(1)		NOT NULL unique auto_increment,
	`name`		VARCHAR(64)	NOT NULL,
	`value`		text		NOT NULL,
	KEY (`id`),
	PRIMARY KEY  (`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE `Users` (
	`id`		int(1)		NOT NULL unique auto_increment,
	`user`		VARCHAR(64)	NOT NULL,
	`password`	text		NOT NULL,
	`name`		text		NOT NULL,
	`groups`	text		NOT NULL,
	`email`		text		NOT NULL,
	`telephone`	text		NOT NULL,
	`address`	text		NOT NULL,
	`enabled`	boolean		NOT NULL,
	`lastUpdate`	TIMESTAMP	NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
	KEY (`id`),
	PRIMARY KEY  (`user`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE `Groups` (
	`id`		int(1)		NOT NULL unique auto_increment,
	`group`		VARCHAR(64)	NOT NULL,
	`description`	text		NOT NULL,
	`lastUpdate`	TIMESTAMP	NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
	KEY (`id`),
	PRIMARY KEY (`group`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE `AccessGroups` (
	`id`		int(1)		NOT NULL unique auto_increment,
	`group`		VARCHAR(64)	NOT NULL,
	`startTime`	VARCHAR(26)	NOT NULL,
	`endTime`	VARCHAR(26)	NOT NULL,
	`network`	VARCHAR(16)	NOT NULL,
	`station`	VARCHAR(16)	NOT NULL,
	`lastUpdate`	TIMESTAMP	NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE `Networks` (
	`id`		int(1)		NOT NULL unique auto_increment,
	`network`	VARCHAR(64)	NOT NULL,
	`description`	text		NOT NULL,
	`lastUpdate`	TIMESTAMP	NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
	KEY (`id`),
	PRIMARY KEY  (`network`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE `NetworkStations` (
	`id`		int(1)		NOT NULL unique auto_increment,
	`network`	VARCHAR(64)	NOT NULL,
	`station`	VARCHAR(64)	NOT NULL,
	`lastUpdate`	TIMESTAMP	NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
	KEY (`id`),
	PRIMARY KEY  (`network`,`station`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE `Stations` (
	`id`		int(1)		NOT NULL unique auto_increment,
	`station`	VARCHAR(16)	NOT NULL,
	`alias`		text		NOT NULL,
	`type`		VARCHAR(16)	NOT NULL,
	`description`	text		NOT NULL,
	`lastUpdate`	TIMESTAMP	NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
	KEY (`id`),
	PRIMARY KEY  (`station`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE `ArrayChannels` (
	`id`			int(1)		NOT NULL unique auto_increment,
	`array`			VARCHAR(16)	NOT NULL,
	`station`		VARCHAR(16)	NOT NULL,
	`channel`		VARCHAR(16)	NOT NULL,
	`order`			int,
	`lastUpdate`		TIMESTAMP	NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE `StationLocations` (
	`id`			int(1)		NOT NULL unique auto_increment,
	`startTime`		VARCHAR(26)	NOT NULL,
	`endTime`		VARCHAR(26)	NOT NULL,
	`network`		VARCHAR(16)	NOT NULL,
	`station`		VARCHAR(16)	NOT NULL,
	`datum`			text		NOT NULL,
	`latitude`		Double		NOT NULL,
	`longitude`		Double		NOT NULL,
	`elevation`		Double		NOT NULL,
	`arrayOffsetEast`	Double		NOT NULL,
	`arrayOffsetNorth`	Double		NOT NULL,
	`lastUpdate`		TIMESTAMP	NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
	KEY (`id`),
	PRIMARY KEY  (`startTime`,`endTime`,`network`,`station`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE `Channels` (
	`id`			int(1)		NOT NULL unique auto_increment,
	`startTime`		VARCHAR(26)	NOT NULL,
	`endTime`		VARCHAR(26)	NOT NULL,
	`network`		VARCHAR(16)	NOT NULL,
	`station`		VARCHAR(16)	NOT NULL,
	`channel`		VARCHAR(16)	NOT NULL,
	`channelType`		VARCHAR(16)	NOT NULL,
	`channelAux`		VARCHAR(16)	NOT NULL,
	`dataType`		VARCHAR(16)	NOT NULL,
	`description`		text		NOT NULL,
	`lastUpdate`		TIMESTAMP	NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
	KEY (`id`),
	PRIMARY KEY  (`startTime`,`endTime`,`network`,`station`,`channel`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE `Sources` (
	`id`			int(1)		NOT NULL unique auto_increment,
	`source`		VARCHAR(16)	NOT NULL,
	`sourceMeta`		VARCHAR(16)	NOT NULL,
	`alias`			text,
	`description`		text,
	`lastUpdate`		TIMESTAMP	NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
	KEY (`id`),
	PRIMARY KEY  (`source`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE `SourcePrioritys` (
	`id`		int(1)		NOT NULL unique auto_increment,
	`startTime`	VARCHAR(26)	NOT NULL,
	`endTime`	VARCHAR(26)	NOT NULL,
	`station`	VARCHAR(16)	NOT NULL,
	`source`	VARCHAR(16)	NOT NULL,
	`priority`	int,
	`lastUpdate`	TIMESTAMP	NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
	KEY (`id`),
	PRIMARY KEY  (`startTime`,`endTime`,`station`,`source`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE `Calibrations` (
	`id`			int(1)		NOT NULL unique auto_increment,
	`startTime`		VARCHAR(26)	NOT NULL,
	`endTime`		VARCHAR(26)	NOT NULL,
	`network`		VARCHAR(16)	NOT NULL,
	`station`		VARCHAR(16)	NOT NULL,
	`channel`		VARCHAR(16)	NOT NULL,
	`source`		VARCHAR(16)	NOT NULL,
	`name`			VARCHAR(16)	NOT NULL,
	`samplingFrequency`	Double		NOT NULL,
	`calibrationFrequency`	Double		NOT NULL,
	`calibrationFactor`	Double		NOT NULL,
	`calibrationUnits`	text		NOT NULL,
	`depth`			Double		NOT NULL,
	`horizontalAngle`	Double		NOT NULL,
	`verticalAngle`		Double		NOT NULL,
	`lastUpdate`		TIMESTAMP	NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
	KEY (`id`),
	PRIMARY KEY  (`startTime`,`endTime`,`network`,`station`,`channel`,`source`,`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE `ChannelInstruments` (
	`id`			int(1)		NOT NULL unique auto_increment,
	`startTime`		VARCHAR(26)	NOT NULL,
	`endTime`		VARCHAR(26)	NOT NULL,
	`channelId`		int(1)		NOT NULL,
	`source`		VARCHAR(16)	NOT NULL,
	`digitiserId`		int(1)		NOT NULL,
	`sensorId`		int(1)		NOT NULL,
	`lastUpdate`		TIMESTAMP	NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
	KEY (`id`),
	PRIMARY KEY  (`startTime`,`endTime`,`channelId`,`source`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE `Digitisers` (
	`id`			int(1)		NOT NULL unique auto_increment,
	`startTime`		VARCHAR(26)	NOT NULL,
	`endTime`		VARCHAR(26)	NOT NULL,
	`name`			VARCHAR(64)	NOT NULL,
	`type`			text		NOT NULL,
	`serialNumber`		text		NOT NULL,
	`numberChannels`	int		NOT NULL,
	`baseSamplingFrequency`	Double		NOT NULL,
	`initialSamplingFrequency`	Double	NOT NULL,
	`gain`			Double		NOT NULL,
	`lastUpdate`		TIMESTAMP	NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE `Sensors` (
	`id`			int(1)		NOT NULL unique auto_increment,
	`startTime`		VARCHAR(26)	NOT NULL,
	`endTime`		VARCHAR(26)	NOT NULL,
	`name`			VARCHAR(64)	NOT NULL,
	`type`			text		NOT NULL,
	`serialNumber`		text		NOT NULL,
	`numberChannels`	int		NOT NULL,
	`gain`			Double		NOT NULL,
	`gainUnits`		text		NOT NULL,
	`oldId`			int		NOT NULL,
	`lastUpdate`		TIMESTAMP	NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE `Responses` (
	`id`			int(1)		NOT NULL unique auto_increment,
	`startTime`		VARCHAR(26)	NOT NULL,
	`endTime`		VARCHAR(26)	NOT NULL,
	`network`		VARCHAR(16)	NOT NULL,
	`station`		VARCHAR(16)	NOT NULL,
	`channel`		VARCHAR(16)	NOT NULL,
	`source`		VARCHAR(16)	NOT NULL,
	`stage`			int		NOT NULL,
	`stageType`		text		NOT NULL,
	`name`			VARCHAR(64)	NOT NULL,
	`type`			text		NOT NULL,
	`data`			mediumtext	NOT NULL,
	`gain`			Double		NOT NULL,
	`gainFrequency`		Double		NOT NULL,
	`filterType`		text		NOT NULL,
	`decimation`		Double		NOT NULL,
	`symmetry`		text		NOT NULL,
	`description`		text		NOT NULL,
	`measured`		boolean		NOT NULL,
	`sampleRate`		Double		NOT NULL,
	`lastUpdate`		TIMESTAMP	NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
	KEY (`id`),
	PRIMARY KEY  (`startTime`,`endTime`,`network`,`station`,`channel`,`source`,`name`,`stage`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE `DataFiles` (
	`id`			int(1)		NOT NULL unique auto_increment,
	`startTime`		VARCHAR(26)	NOT NULL,
	`endTime`		VARCHAR(26)	NOT NULL,
	`location`		VARCHAR(256)	NOT NULL,
	`format`		text		NOT NULL,
	`url`			text		NOT NULL,
	`comment`		text		NOT NULL,
	`importUserId`		int,
	`importTime`		VARCHAR(26),
	`state`			VARCHAR(16),
	`lastUpdate`		TIMESTAMP	NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE `DataChannels` (
	`id`			int(1)		NOT NULL unique auto_increment,
	`startTime`		VARCHAR(26)	NOT NULL,
	`endTime`		VARCHAR(26)	NOT NULL,
	`network`		VARCHAR(16)	NOT NULL,
	`station`		VARCHAR(16)	NOT NULL,
	`channel`		VARCHAR(16)	NOT NULL,
	`source`		VARCHAR(16)	NOT NULL,
	`numBlocks`		int		NOT NULL,
	`numSamples`		bigint		NOT NULL,
	`sampleRate`		Double		NOT NULL,
	`sampleFormat`		int		NOT NULL,
	`dataFileId`		int(1)		NOT NULL,
	`dataFileChannel`	int(1)		NOT NULL,
	`importFormat`		text		NOT NULL,
	`importFilename`	text		NOT NULL,
	`importStartTime`	VARCHAR(26)	NOT NULL,
	`lastUpdate`		TIMESTAMP	NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
	KEY (`id`),
	KEY (`startTime`),
	KEY (`endTime`),
	KEY (`network`,`station`,`source`,`channel`),
	KEY (`dataFileId`),
	PRIMARY KEY  (`startTime`,`endTime`,`network`,`station`,`source`,`channel`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE `Notes` (
	`id`			int(1)		NOT NULL unique auto_increment,
	`startTime`		VARCHAR(26)	NOT NULL,
	`endTime`		VARCHAR(26)	NOT NULL,
	`network`		VARCHAR(16)	NOT NULL,
	`station`		VARCHAR(16)	NOT NULL,
	`channel`		VARCHAR(16)	NOT NULL,
	`source`		VARCHAR(16)	NOT NULL,
	`type`			VARCHAR(32)	NOT NULL,
	`user`			text		NOT NULL,
	`timeAdded`		VARCHAR(26)	NOT NULL,
	`errorNumber`		int		NOT NULL,
	`title`			text		NOT NULL,
	`description`		text		NOT NULL,
	`docFormat`		text		NOT NULL,
	`docUrl`		text		NOT NULL,
	`dataFileId`		int		NOT NULL,
	`importFilename`	text		NOT NULL,
	`lastUpdate`		TIMESTAMP	NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE `Logs` (
	`id`			int(1)		NOT NULL unique auto_increment,
	`time`			VARCHAR(26)	NOT NULL,
	`type`			VARCHAR(16)	NOT NULL,
	`priority`		int(1)		NOT NULL,
	`subSystem`		VARCHAR(32)	NOT NULL,
	`title`			text		NOT NULL,
	`description`		text		NOT NULL,
	`lastUpdate`		TIMESTAMP	NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE `Changes` (
	`id`			int(1)		NOT NULL unique auto_increment,
	`changeGroupId`		int(1)		NOT NULL,
	`type`			VARCHAR(26)	NOT NULL,
	`time`			VARCHAR(26)	NOT NULL,
	`table`			VARCHAR(64)	NOT NULL,
	`rowId`			int(1)		NOT NULL,
	`lastUpdate`		TIMESTAMP	NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
	KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE `ChangeGroups` (
	`id`			int(1)		NOT NULL unique auto_increment,
	`type`			VARCHAR(64)	NOT NULL,
	`time`			VARCHAR(26)	NOT NULL,
	`user`			VARCHAR(64)	NOT NULL,
	`title`			text		NOT NULL,
	`description`		text		NOT NULL,
	`lastUpdate`		TIMESTAMP	NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
	KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


/*
CREATE TABLE `` (
	`id`		int(1)		NOT NULL unique auto_increment,
	`startTime`	VARCHAR(26)	NOT NULL,
	`endTime`	VARCHAR(26)	NOT NULL,
	`network`	VARCHAR(16)	NOT NULL,
	`station`	VARCHAR(16)	NOT NULL,
	PRIMARY KEY  (`startTime`,`endTime`,`network`,`station`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE `` (
	`id`		int(1)		NOT NULL unique auto_increment,
	`startTime`	VARCHAR(26)	NOT NULL,
	`endTime`	VARCHAR(26)	NOT NULL,
	`network`	VARCHAR(16)	NOT NULL,
	`station`	VARCHAR(16)	NOT NULL,
	PRIMARY KEY  (`startTime`,`endTime`,`network`,`station`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

*/
